Module: SFML
- Defined in:
- lib/sfml.rb,
lib/sfml/c.rb,
lib/sfml/game.rb,
lib/sfml/assets.rb,
lib/sfml/c/audio.rb,
lib/sfml/version.rb,
lib/sfml/c/system.rb,
lib/sfml/c/window.rb,
lib/sfml/c/network.rb,
lib/sfml/c/graphics.rb,
lib/sfml/audio/music.rb,
lib/sfml/audio/sound.rb,
lib/sfml/network/ftp.rb,
lib/sfml/system/rect.rb,
lib/sfml/system/time.rb,
lib/sfml/network/http.rb,
lib/sfml/system/clock.rb,
lib/sfml/window/event.rb,
lib/sfml/window/mouse.rb,
lib/sfml/window/touch.rb,
lib/sfml/graphics/font.rb,
lib/sfml/graphics/text.rb,
lib/sfml/graphics/view.rb,
lib/sfml/window/cursor.rb,
lib/sfml/window/sensor.rb,
lib/sfml/window/window.rb,
lib/sfml/audio/internal.rb,
lib/sfml/audio/listener.rb,
lib/sfml/graphics/color.rb,
lib/sfml/graphics/image.rb,
lib/sfml/system/vector2.rb,
lib/sfml/system/vector3.rb,
lib/sfml/graphics/shader.rb,
lib/sfml/graphics/sprite.rb,
lib/sfml/graphics/vertex.rb,
lib/sfml/window/joystick.rb,
lib/sfml/window/keyboard.rb,
lib/sfml/audio/sound_cone.rb,
lib/sfml/graphics/texture.rb,
lib/sfml/window/clipboard.rb,
lib/sfml/window/video_mode.rb,
lib/sfml/audio/sound_buffer.rb,
lib/sfml/audio/sound_stream.rb,
lib/sfml/graphics/transform.rb,
lib/sfml/network/ip_address.rb,
lib/sfml/network/tcp_socket.rb,
lib/sfml/network/udp_socket.rb,
lib/sfml/graphics/blend_mode.rb,
lib/sfml/audio/sound_recorder.rb,
lib/sfml/network/tcp_listener.rb,
lib/sfml/graphics/circle_shape.rb,
lib/sfml/graphics/convex_shape.rb,
lib/sfml/graphics/stencil_mode.rb,
lib/sfml/graphics/vertex_array.rb,
lib/sfml/graphics/render_states.rb,
lib/sfml/graphics/render_target.rb,
lib/sfml/graphics/render_window.rb,
lib/sfml/graphics/transformable.rb,
lib/sfml/graphics/vertex_buffer.rb,
lib/sfml/graphics/render_texture.rb,
lib/sfml/network/socket_selector.rb,
lib/sfml/graphics/rectangle_shape.rb,
lib/sfml/audio/sound_buffer_recorder.rb
Defined Under Namespace
Modules: Assets, Audio, C, Clipboard, Graphics, Joystick, Keyboard, Listener, Mouse, Network, Sensor, SoundRecorder, Touch Classes: BlendMode, CircleShape, Clock, Color, ConvexShape, Cursor, Error, Event, Font, Game, Image, LoadError, Music, Rect, RectangleShape, RenderStates, RenderTexture, RenderWindow, Shader, Sound, SoundBuffer, SoundBufferRecorder, SoundCone, SoundStream, Sprite, StencilMode, Text, Texture, Time, Transform, Vector2, Vector3, Vertex, VertexArray, VertexBuffer, VideoMode, View, Window
Constant Summary collapse
- CSFML_VERSION =
The SFML/CSFML release this gem is built against. End users can check this at runtime to assert binding compatibility.
"3.0.0"- VERSION =
Gem version. The first three segments mirror CSFML_VERSION exactly; the trailing fourth segment is our own patch number for fixes / additions made on top of the same upstream CSFML release.
Examples on a hypothetical timeline:
"3.0.0.0" — first cut against CSFML 3.0.0 "3.0.0.1" — our bug fix, still on CSFML 3.0.0 "3.0.0.2" — another patch "3.0.1.0" — CSFML 3.0.1 ships, we re-cut from upstream "3.0.1.1" — our patch on top of CSFML 3.0.1 "3.1.0.0" — CSFML 3.1.0 ships, we add new bindings "3.0.0.1"