Class: SFML::C::System::InputStream
- Inherits:
-
FFI::Struct
- Object
- FFI::Struct
- SFML::C::System::InputStream
- Defined in:
- lib/sfml/c/system.rb
Overview
sfInputStream — a struct of 4 function pointers Ruby fills in to expose a Ruby IO-like object to CSFML’s loader functions. User-data is ignored; we close over the Ruby object in each callback closure directly.